@@ -1,5 +1,5 @@
 /* Copyright (C) 2004 Bart
- * Copyright (C) 2008 Curtis Gedak
+ * Copyright (C) 2008, 2009, 2010 Curtis Gedak
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -36,7 +36,8 @@ public:
 		       unsigned short new_count,
 		       const std::vector<FS> & FILESYSTEMS,
 		       bool only_unformatted,
-		       Sector cylinder_size );
+		       Sector cylinder_size,
+		       Glib::ustring disktype );
 	Partition Get_New_Partition() ;//overridden function
 
 private:
