@@ -209,7 +209,10 @@ void Win_GParted::init_toolbar()
 	hbox_toolbar.pack_start( toolbar_main );
 	
 	//NEW and DELETE
-	toolbutton = Gtk::manage( new Gtk::ToolButton( Gtk::Stock::NEW ) );
+	image = manage( new Gtk::Image( Gtk::Stock::NEW, Gtk::ICON_SIZE_BUTTON ) );
+	/*TO TRANSLATORS: "New" is a tool bar item for partition actions. */
+	Glib::ustring str_temp = _("New") ;
+	toolbutton = Gtk::manage(new Gtk::ToolButton( *image, str_temp ));
 	toolbutton ->signal_clicked() .connect( sigc::mem_fun( *this, &Win_GParted::activate_new ) );
 	toolbar_main .append( *toolbutton );
 	TOOLBAR_NEW = index++ ;
@@ -224,7 +227,7 @@ void Win_GParted::init_toolbar()
 	
 	//RESIZE/MOVE
 	image = manage( new Gtk::Image( Gtk::Stock::GOTO_LAST, Gtk::ICON_SIZE_BUTTON ) );
-	Glib::ustring str_temp = _("Resize/Move") ;
+	str_temp = _("Resize/Move") ;
 	//Condition string split and Undo button.
 	//  for longer translated string, split string in two and skip the Undo button to permit full toolbar to display
 	//  FIXME:  Is there a better way to do this, perhaps without the conditional?  At the moment this seems to be the best compromise.
@@ -293,8 +296,11 @@ void Win_GParted::init_partition_menu()
 {
 	int index = 0 ;
 	//fill menu_partition
+	image = manage( new Gtk::Image( Gtk::Stock::NEW, Gtk::ICON_SIZE_MENU ) );
 	menu_partition .items() .push_back( 
-			Gtk::Menu_Helpers::StockMenuElem( Gtk::Stock::NEW,
+			/*TO TRANSLATORS: "_New" is a sub menu item for the partition menu. */
+			Gtk::Menu_Helpers::ImageMenuElem( _("_New"), 
+							  *image, 
 							  sigc::mem_fun(*this, &Win_GParted::activate_new) ) );
 	MENU_NEW = index++ ;
 	
@@ -510,7 +516,15 @@ void Win_GParted::init_device_info()
 			Gtk::FILL );
 	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
 	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
-	
+
+	//sector size
+	table ->attach( * Utils::mk_label( " <b>" + static_cast<Glib::ustring>( _("Sector size:") ) + "</b>" ),
+			0, 1,
+			top, bottom,
+			Gtk::FILL );
+	device_info .push_back( Utils::mk_label( "", true, Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER, false, true ) ) ;
+	table ->attach( * device_info .back(), 1, 2, top++, bottom++, Gtk::FILL ) ;
+
 	vbox_info .pack_start( *table, Gtk::PACK_SHRINK );
 }
 
@@ -640,6 +654,7 @@ void Win_GParted::Fill_Label_Device_Info( bool clear )
 		device_info[ t++ ] ->set_text( Utils::num_to_str( devices[ current_device ] .sectors ) );
 		device_info[ t++ ] ->set_text( Utils::num_to_str( devices[ current_device ] .cylinders ) );
 		device_info[ t++ ] ->set_text( Utils::num_to_str( devices[ current_device ] .length ) );
+		device_info[ t++ ] ->set_text( Utils::num_to_str( devices[ current_device ] .sector_size ) );
 	}
 }
 
@@ -1501,7 +1516,8 @@ void Win_GParted::activate_new()
 				  new_count,
 				  gparted_core .get_filesystems(),
 				  devices[ current_device ] .readonly,
-				  devices[ current_device ] .cylsize ) ;
+				  devices[ current_device ] .cylsize,
+				  devices[ current_device ] .disktype ) ;
 		
 		dialog .set_transient_for( *this );
 		
